@@ -1,6 +1,6 @@
 package Text::vCard::Precisely;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 use Moose;
 use Moose::Util::TypeConstraints;
@@ -8,14 +8,14 @@ use Moose::Util::TypeConstraints;
 extends 'Text::vCard::Precisely::V3';
 
 enum 'Version' => [qw( 3.0 4.0 )];
-has version => ( is => 'ro', isa => 'Version', default => '3.0', required => 1 );
+has version    => ( is => 'ro', isa => 'Version', default => '3.0', required => 1 );
 
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
 sub BUILD {
     my $self = shift;
-    return Text::vCard::Precisely::V3->new(@_) unless $self->version eq '4.0';
+    return Text::vCard::Precisely::V3->new(@_) unless $self->version() eq '4.0';
 
     require Text::vCard::Precisely::V4;
     return Text::vCard::Precisely::V4->new(@_);
@@ -34,8 +34,9 @@ Text::vCard::Precisely - Read, Write and Edit the vCards 3.0 and/or 4.0 precisel
 =head1 SYNOPSIS
 
  my $vc = Text::vCard::Precisely->new();
- # or now you can write like below if you want to use 4.0:
- #my $vc = Text::vCard::Precisely->new( version => '4.0' );
+ # Or now you can write like below if you want to use 4.0:
+ my $vc4 = Text::vCard::Precisely->new( version => '4.0' );
+ #or $vc4 = Text::vCard::Precisely::V4->new();
 
  $vc->n([ 'Gump', 'Forrest', , 'Mr', '' ]);
  $vc->fn( 'Forrest Gump' );
@@ -43,7 +44,7 @@ Text::vCard::Precisely - Read, Write and Edit the vCards 3.0 and/or 4.0 precisel
  use GD;
  use MIME::Base64;
 
- my $img = GD->new( ... some param ... )->plot->png;
+ my $img = GD->new( ... some param ... )->plot()->png();
  my $base64 = MIME::Base64::encode($img);
 
  $vc->photo([
@@ -65,19 +66,20 @@ Text::vCard::Precisely - Read, Write and Edit the vCards 3.0 and/or 4.0 precisel
     street    => 'Waters Edge',
     city      => 'Baytown',
     region    => 'LA',
-    post_code => '30314,
+    post_code => '30314',
     country   => 'United States of America',
  });
 
  $vc->url({ content => 'https://twitter.com/worthmine', types => ['twitter'] }); # for URL param
+
  print $vc->as_string();
 
 =head1 DESCRIPTION
 
 A vCard is a digital business card.
-vCard and L<Text::vFile::asData|https://github.com/richardc/perl-text-vfile-asdata> provides an API for parsing vCards
+vCard and L<Text::vFile::asData|https://metacpan.org/pod/Text::vFile::asData> provides an API for parsing vCards
 
-This module is forked from L<Text::vCard|https://github.com/ranguard/text-vcard>
+This module is forked from L<Text::vCard|https://metacpan.org/pod/Text::vCard>
 because some reason below:
 
 =over
@@ -97,7 +99,7 @@ Android 4.4.x can't parse vCard4.0
 =back
 
 To handle an address book with several vCard entries in it, start with
-L<Text::vFile::asData|https://github.com/richardc/perl-text-vfile-asdata> and then come back to this module.
+L<Text::vFile::asData|https://metacpan.org/pod/Text::vFile::asData> and then come back to this module.
 
 Note that the vCard RFC requires version() and full_name().  This module does not check or warn yet if these conditions have not been met
 
@@ -377,13 +379,17 @@ I don't know well about in Android or Windows. Somebody please feedback me
 
 B<It's DEPRECATED from 4.0> You can use this method Just ONLY in vCard3.0
 
-=head2 aroud UTF-8
+=head1 For operating files with multiple vCards
+
+See L<Text::vCard::Precisely::Multiple|https://metacpan.org/pod/Text::vCard::Precisely::Multiple>
+
+=head1 aroud UTF-8
 
 If you want to send precisely the vCard with UTF-8 characters to the B<ALMOST> of smartphones, Use 3.0
 
 It seems to be TOO EARLY to use 4.0
 
-=head2 for under perl-5.12.5
+=head1 for under perl-5.12.5
 
 This module uses C<\P{ascii}> in regexp so You have to use 5.12.5 and later
 
@@ -407,7 +413,11 @@ L<RFC 6350|https://tools.ietf.org/html/rfc6350>
 
 =item
 
-L<Text::vFile::asData|https://github.com/richardc/perl-text-vfile-asdata>
+L<Text::vCard::Precisely::Multiple|https://metacpan.org/pod/Text::vCard::Precisely::Multiple>
+
+=item
+
+L<Text::vFile::asData|https://metacpan.org/pod/Text::vFile::asData>
 
 =back
 
