@@ -1,6 +1,6 @@
 package Text::vCard::Precisely::Multiple;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 use Moose;
 use Moose::Util::TypeConstraints;
@@ -8,49 +8,49 @@ use Moose::Util::TypeConstraints;
 use Carp;
 use Text::vCard::Precisely;
 use Text::vFile::asData;
-my $vf = Text::vFile::asData->new;
+my $vf = Text::vFile::asData->new();
 use Path::Tiny;
 
 enum 'Version' => [qw( 3.0 4.0 )];
-has version => ( is => 'ro', isa => 'Version', default => '3.0', required => 1 );
+has version    => ( is => 'ro', isa => 'Version', default => '3.0', required => 1 );
 
 subtype 'vCards' => as 'ArrayRef[Text::vCard::Precisely]';
-coerce 'vCards',
-    from 'Text::vCard::Precisely',
-    via {[ $_[0] ]};
+coerce 'vCards', from 'Text::vCard::Precisely', via { [ $_[0] ] };
 has options => (
     traits  => ['Array'],
-    is => 'ro',
-    isa => 'vCards',
-    coerce => 1,
+    is      => 'ro',
+    isa     => 'vCards',
+    coerce  => 1,
     default => sub { [] },
     handles => {
-        all_options    => 'elements',
-        add_option     => 'push',
-        clear_options  => 'clear',
-#        map_options    => 'map',
-#        filter_options => 'grep',
-#        find_option    => 'first',
-#        get_option     => 'get',
-#        join_options   => 'join',
-        count_options  => 'count',
-#        has_options    => 'count',
+        all_options   => 'elements',
+        add_option    => 'push',
+        clear_options => 'clear',
+
+        #        map_options    => 'map',
+        #        filter_options => 'grep',
+        #        find_option    => 'first',
+        #        get_option     => 'get',
+        #        join_options   => 'join',
+        count_options => 'count',
+
+        #        has_options    => 'count',
         has_no_options => 'is_empty',
-#        sorted_options => 'sort',
+
+        #        sorted_options => 'sort',
     },
 );
 
-
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
 sub load_arrayref {
     my $self = shift;
-    my $ref = shift;
+    my $ref  = shift;
     croak "Attribute must be an ArrayRef: $ref" unless ref($ref) eq 'ARRAY';
     $self->clear_options();
-    
-    foreach my $data (@$ref){
+
+    foreach my $data (@$ref) {
         my $vc = Text::vCard::Precisely->new( version => $self->version() );
         $self->add_option( $vc->load_hashref($data) );
     }
@@ -58,16 +58,16 @@ sub load_arrayref {
 }
 
 sub load_file {
-    my $self = shift;
+    my $self     = shift;
     my $filename = shift;
     open my $vcf, "<", $filename or croak "couldn't open vcf: $!";
     my $objects = $vf->parse($vcf)->{'objects'};
     close $vcf;
-    
+
     $self->clear_options();
-    foreach my $data (@$objects){
+    foreach my $data (@$objects) {
         croak "$filename contains unvalid vCard data." unless $data->{'type'} eq 'VCARD';
-        my $vc = Text::vCard::Precisely->new( version => $self->version() );
+        my $vc      = Text::vCard::Precisely->new( version => $self->version() );
         my $hashref = $vc->_make_hashref($data);
         $self->add_option( $vc->load_hashref($hashref) );
     }
@@ -76,9 +76,9 @@ sub load_file {
 
 sub as_string {
     my $self = shift;
-    my $str = '';
-    foreach my $vc ( $self->all_options() ){
-       $str .= $vc->as_string();
+    my $str  = '';
+    foreach my $vc ( $self->all_options() ) {
+        $str .= $vc->as_string();
     }
     return $str;
 }
@@ -86,9 +86,9 @@ sub as_string {
 sub as_file {
     my ( $self, $filename ) = @_;
     croak "No filename was set!" unless $filename;
-    
+
     my $file = path($filename);
-    $file->spew( {binmode => ":encoding(UTF-8)"}, $self->as_string() );
+    $file->spew( { binmode => ":encoding(UTF-8)" }, $self->as_string() );
     return $file;
 }
 
@@ -156,11 +156,11 @@ Text::vCard::Precisely::Multiple - some add-on for Text::vCard::Precisely
 
  and
 
- $vcm->as_string();;;
+ $vcm->as_string();
 
  or
 
- $vcm->as_file('outp;ut.vcf');
+ $vcm->as_file('output.vcf');
 
 =cut
 
@@ -195,7 +195,8 @@ Accepts an ArrayRef that looks like below:
         }],
         EMAIL => 'forrestgump@example.com',
         REV => '20080424T195243Z',
-    },{...};
+    },{...}
+ ];
 
 =head2 load_file($file_name)
 
@@ -221,9 +222,9 @@ These methods accept and return strings
 returns Version number of the vcard.
 Defaults to B<'3.0'> and this method is B<READONLY>
 
-=head2 aroud UTF-8
+=head1 aroud UTF-8
 
-=head2 for under perl-5.12.5
+=head1 for under perl-5.12.5
 
 This module uses Text::vCard::Precisely and it require you to use 5.12.5 and later
 
@@ -245,7 +246,7 @@ L<RFC 6350|https://tools.ietf.org/html/rfc6350>
 
 =item
 
-L<Text::vFile::asData|https://github.com/richardc/perl-text-vfile-asdata>
+L<Text::vFile::asData|https://metacpan.org/pod/Text::vFile::asData>
 
 =back
 
