@@ -1,7 +1,7 @@
 # ABSTRACT: turns baubles into trinkets
 package Text::vCard::Precisely::V3;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 use 5.8.9;
 
@@ -23,10 +23,10 @@ use Path::Tiny;
 Text::vCard::Precisely::V3 - Read, Write and Edit B<just ONLY vCards 3.0> precisely
 
 =head1 SYNOPSIS
-
- my $vc = Text::vCard::Precisely->new( version => '3.0' );
+ my $vc = Text::vCard::Precisely->new();
  # Or you can write like below if you want to be expressly using 3.0:
- #my $vc = Text::vCard::Precisely::V3->new();
+ my $vc3 = Text::vCard::Precisely->new( version => '3.0' );
+ #or $vc3 = Text::vCard::Precisely::V3->new();
 
  $vc->n([ 'Gump', 'Forrest', , 'Mr', '' ]);
  $vc->fn( 'Forrest Gump' );
@@ -34,7 +34,7 @@ Text::vCard::Precisely::V3 - Read, Write and Edit B<just ONLY vCards 3.0> precis
  use GD;
  use MIME::Base64;
 
- my $img = GD->new( ... some param ... )->plot->png;
+ my $img = GD->new( ... some param ... )->plot()->png();
  my $base64 = MIME::Base64::encode($img);
 
  $vc->photo([
@@ -62,36 +62,13 @@ Text::vCard::Precisely::V3 - Read, Write and Edit B<just ONLY vCards 3.0> precis
 
  $vc->url({ content => 'https://twitter.com/worthmine', types => ['twitter'] }); # for URL param
 
-And you can use X-SOCIALPROFILE type if you want like below:
-
- use Facebook::Graph;
- use Encode;
-
- my $fb = Facebook::Graph->new(
-    app_id => 'your app id',
-    secret => 'your secret key',
- );
- $fb->authorize;
- $fb->access>token( $fb->{'app_id'} . '|' . $fb->{'secret'} );
- my $q = $fb->query->find( 'some facebookID' )
- ->select>fields(qw( id name ))
- ->request
- ->as_hashref;
-
- $vc->socialprofile({ # Now you can set X-Social-Profile but Android ignore it
-    content => 'https://www.facebook/' . 'some facebookID',
-    types => 'facebook',
-    displayname => encode_utf8( $q->{'name'} ),
-    userid => $q->{'id'},
- });
-
  print $vc->as_string();
 
 =head1 DESCRIPTION
 
-A vCard is a digital business card. vCard and L<Text::vFile::asData|https://github.com/richardc/perl-text-vfile-asdata> provide an API for parsing vCards.
+A vCard is a digital business card. vCard and L<Text::vFile::asData|https://metacpan.org/pod/Text::vFile::asData> provide an API for parsing vCards.
 
-This module is forked from L<Text::vCard|https://github.com/ranguard/text-vcard> because some reason below:
+This module is forked from L<Text::vCard|https://metacpan.org/pod/Text::vCard> because some reason below:
 
 =over
 
@@ -110,7 +87,7 @@ Android 4.4.x can't parse vCard4.0
 =back
 
 To handle an address book with several vCard entries in it, start with
-L<Text::vFile::asData|https://github.com/richardc/perl-text-vfile-asdata> and then come back to this module.
+L<Text::vFile::asData|https://metacpan.org/pod/Text::vFile::asData> and then come back to this module.
 
 Note that the vCard RFC requires FN type.
 And this module does not check or warn if these conditions have not been met.
@@ -118,7 +95,7 @@ And this module does not check or warn if these conditions have not been met.
 =cut
 
 use Text::vFile::asData;
-my $vf = Text::vFile::asData->new({ preserve_params => 1 });
+my $vf = Text::vFile::asData->new( { preserve_params => 1 } );
 
 use Text::vCard::Precisely::V3::Node;
 use Text::vCard::Precisely::V3::Node::N;
@@ -181,9 +158,11 @@ sub load_hashref {
         next unless $method and $content;
         if ( ref $content eq 'Hash' ) {
             $self->$method( { name => uc($key), %$content } );
-        }elsif( ref $content eq 'Array'  ){
-            $self->$method({ name => uc($key), @$content });
-        }else{
+        }
+        elsif ( ref $content eq 'Array' ) {
+            $self->$method( { name => uc($key), @$content } );
+        }
+        else {
             $self->$method($content);
         }
     }
@@ -201,10 +180,10 @@ sub load_file {
     open my $vcf, "<", $filename or croak "couldn't open vcf: $!";
     my $data = $vf->parse($vcf)->{'objects'}[0];
     close $vcf;
-    
+
     croak "$filename is NOT a vCard file." unless $data->{'type'} eq 'VCARD';
 
-    my $hashref = $self->_make_hashref($data->{'properties'});
+    my $hashref = $self->_make_hashref( $data->{'properties'} );
     $self->load_hashref($hashref);
 }
 
@@ -216,39 +195,44 @@ Accepts a vCard string
 
 sub load_string {
     my ( $self, $str ) = @_;
-    my @lines = split /\r\n/, $str;
-    my $data = $vf->parse_lines(@lines);
-    my $hashref = $self->_make_hashref($data->{'objects'}[0]->{properties});
+    my @lines   = split /\r\n/, $str;
+    my $data    = $vf->parse_lines(@lines);
+    my $hashref = $self->_make_hashref( $data->{'objects'}[0]->{properties} );
     $self->load_hashref($hashref);
 }
 
 sub _make_hashref {
     my ( $self, $data ) = @_;
     my $hashref = {};
-    while( my( $name, $content ) = each %{$data->{'properties'}} ){
+    while ( my ( $name, $content ) = each %{ $data->{'properties'} } ) {
         next if $name eq 'VERSION';
         foreach my $node (@$content) {
-            if( $name eq 'N' ){
+            if ( $name eq 'N' ) {
                 my @names = split /(?<!\\);/, $node->{'value'};
                 $hashref->{$name} ||= \@names;
-            }elsif( $name eq 'TEL' ){
+            }
+            elsif ( $name eq 'TEL' ) {
                 my $content = $node->{'value'};
                 $hashref->{$name} = [] unless exists $hashref->{$name};
-                if( ref($node->{'params'}) eq 'ARRAY' ){
-                    my @types = map{ values %$_ } @{$node->{'params'}};
-                    push @{$hashref->{$name}}, { types => \@types, content => $content };
-                }elsif( ref($node->{'param'}) eq 'HASH' ){
-                    push my @types, sort @{$node->{'params'}} if ref $node->{'params'};
-                    push @{$hashref->{$name}}, { types => \@types, content => $content };
-                }else{
+                if ( ref( $node->{'params'} ) eq 'ARRAY' ) {
+                    my @types = map { values %$_ } @{ $node->{'params'} };
+                    push @{ $hashref->{$name} }, { types => \@types, content => $content };
+                }
+                elsif ( ref( $node->{'param'} ) eq 'HASH' ) {
+                    push my @types, sort @{ $node->{'params'} } if ref $node->{'params'};
+                    push @{ $hashref->{$name} }, { types => \@types, content => $content };
+                }
+                else {
                     push my @types, $node->{'param'};
-                    push @{$hashref->{$name}}, { types => \@types, content => $content };
+                    push @{ $hashref->{$name} }, { types => \@types, content => $content };
                 }
                 $hashref->{$name} ||= $content;
-            }elsif( $name eq 'REV' ){
+            }
+            elsif ( $name eq 'REV' ) {
                 $hashref->{$name} ||= $node->{'value'};
-            }elsif( $name eq 'ADR' ){
-                my $ref = $self->_parse_param($node);
+            }
+            elsif ( $name eq 'ADR' ) {
+                my $ref      = $self->_parse_param($node);
                 my @addesses = split /(?<!\\);/, $node->{'value'};
                 $ref->{'pobox'}     = $addesses[0];
                 $ref->{'extended'}  = $addesses[1];
@@ -257,11 +241,12 @@ sub _make_hashref {
                 $ref->{'region'}    = $addesses[4];
                 $ref->{'post_code'} = $addesses[5];
                 $ref->{'country'}   = $addesses[6];
-                push @{$hashref->{$name}}, $ref;
-            }else{
+                push @{ $hashref->{$name} }, $ref;
+            }
+            else {
                 my $ref = $self->_parse_param($node);
                 $ref->{'content'} = $node->{'value'};
-                push @{$hashref->{$name}}, $ref;
+                push @{ $hashref->{$name} }, $ref;
             }
         }
     }
@@ -271,8 +256,8 @@ sub _make_hashref {
 sub _parse_param {
     my ( $self, $content ) = @_;
     my $ref = {};
-    $ref->{'types'} = [split /,/, $content->{'param'}{'TYPE'}] if $content->{'param'}{'TYPE'};
-    $ref->{'pref'} = $content->{'param'}{'PREF'} if $content->{'param'}{'PREF'};
+    $ref->{'types'} = [ split /,/, $content->{'param'}{'TYPE'} ] if $content->{'param'}{'TYPE'};
+    $ref->{'pref'}  = $content->{'param'}{'PREF'}                if $content->{'param'}{'PREF'};
     return $ref;
 }
 
@@ -288,14 +273,16 @@ You have to use Encode::encode_utf8() if your vCard is written in utf8
 my $cr = "\x0D\x0A";
 our $will_be_deprecated = [qw(name profile mailer agent class)];
 
-my @types = ( qw(
-    FN N NICKNAME
-    ADR LABEL TEL EMAIL GEO
-    ORG TITLE ROLE CATEGORIES
-    NOTE SOUND UID URL KEY
-    SOCIALPROFILE PHOTO LOGO SOURCE
-    SORT-STRING
-), map{uc} @$will_be_deprecated );
+my @types = (
+    qw(
+        FN N NICKNAME
+        ADR LABEL TEL EMAIL GEO
+        ORG TITLE ROLE CATEGORIES
+        NOTE SOUND UID URL KEY
+        SOCIALPROFILE PHOTO LOGO SOURCE
+        SORT-STRING
+        ), map {uc} @$will_be_deprecated
+);
 
 sub as_string {
     my ($self) = @_;
@@ -319,22 +306,26 @@ sub _header {
 
 sub _make_types {
     my $self = shift;
-    my $str = '';
+    my $str  = '';
     foreach my $node (@_) {
         $node =~ tr/-/_/;
         my $method = $self->can( lc $node );
         croak "the Method you provided, $node is not supported." unless $method;
-        if( ref $self->$method eq 'ARRAY' ) {
-            foreach my $item ( @{ $self->$method } ){
-                if( $item->isa('Text::vCard::Precisely::V3::Node') ){
+        if ( ref $self->$method eq 'ARRAY' ) {
+            foreach my $item ( @{ $self->$method } ) {
+                if ( $item->isa('Text::vCard::Precisely::V3::Node') ) {
                     $str .= $item->as_string();
-                }elsif($item){
+                }
+                elsif ($item) {
                     $str .= uc($node) . ":" . $item->as_string() . $cr;
                 }
             }
-        }elsif( $self->$method() and $self->$method()->isa('Text::vCard::Precisely::V3::Node::N') ){
+        }
+        elsif ( $self->$method() and $self->$method()->isa('Text::vCard::Precisely::V3::Node::N') )
+        {
             $str .= $self->$method()->as_string();
-        }elsif( $self->$method ){
+        }
+        elsif ( $self->$method ) {
             $str .= $self->$method();
         }
     }
@@ -343,7 +334,7 @@ sub _make_types {
 
 sub _footer {
     my $self = shift;
-    my $str = '';
+    my $str  = '';
     map { $str .= "TZ:" . $_->name() . $cr } @{ $self->tz() } if $self->tz();
     $str .= 'REV:' . $self->rev() . $cr if $self->rev();
     $str .= "END:VCARD";
@@ -352,12 +343,12 @@ sub _footer {
 
 sub _fold {
     my $self = shift;
-    my $str = shift or croak "Can't fold empty strings!";
-    my $lf = Text::LineFold->new(   # line break with 75bytes
-        CharMax => 74,
-        Charset => $self->encoding_in(),
+    my $str  = shift or croak "Can't fold empty strings!";
+    my $lf   = Text::LineFold->new(                          # line break with 75bytes
+        CharMax       => 74,
+        Charset       => $self->encoding_in(),
         OutputCharset => $self->encoding_out(),
-        Newline => $cr,
+        Newline       => $cr,
     );
     $str = $lf->fold( "", "  ", $str );
     return $str;
@@ -373,8 +364,9 @@ Dies if not successful.
 sub as_file {
     my ( $self, $filename ) = @_;
     croak "No filename was set!" unless $filename;
-    
+
     my $file = path($filename);
+
     #$file->spew( {binmode => ":encoding(UTF-8)"}, $self->as_string() );
     $file->spew_utf8( $self->as_string() );
     return $file;
@@ -387,6 +379,7 @@ These methods accept and return strings
 =head2 version()
 
 returns Version number of the vcard. Defaults to B<'3.0'> and this method is B<READONLY>
+
 =cut
 
 has version => ( is => 'ro', isa => 'Str', default => '3.0' );
@@ -397,18 +390,12 @@ To specify revision information about the current vCard3.0
 
 =cut
 
-subtype 'TimeStamp'
-    => as 'Str'
-    => where { m/^\d{4}-?\d{2}-?\d{2}(:?T\d{2}:?\d{2}:?\d{2}Z)?$/is }
-    => message { "The TimeStamp you provided, $_, was not correct" };
-coerce 'TimeStamp',
-    from 'Int',
-    via {
-        my ( $s, $m, $h, $d, $M, $y ) = gmtime($_);
-        return sprintf '%4d-%02d-%02dT%02d:%02d:%02dZ', $y + 1900, $M + 1, $d, $h, $m, $s
-    },
-    from 'ArrayRef[HashRef]',
-    via { $_->[0]{'content'} };
+subtype 'TimeStamp' => as 'Str' => where {m/^\d{4}-?\d{2}-?\d{2}(?:T\d{2}:?\d{2}:?\d{2}Z)?$/is}
+=> message {"The TimeStamp you provided, $_, was not correct"};
+coerce 'TimeStamp', from 'Int', via {
+    my ( $s, $m, $h, $d, $M, $y ) = gmtime($_);
+    return sprintf '%4d-%02d-%02dT%02d:%02d:%02dZ', $y + 1900, $M + 1, $d, $h, $m, $s
+}, from 'ArrayRef[HashRef]', via { $_->[0]{'content'} };
 has rev => ( is => 'rw', isa => 'TimeStamp', coerce => 1 );
 
 =head2 name(), profile(), mailer(), agent(), class();
@@ -433,27 +420,26 @@ To specify the components of the name of the object the vCard represents.
 =cut
 
 subtype 'N' => as 'Text::vCard::Precisely::V3::Node::N';
-coerce 'N',
-    from 'HashRef[Maybe[Ref]|Maybe[Str]]',
-    via {
-        my %param;
-        while( my ($key, $content) = each %$_ ) {
-            $param{$key} = $content if $content;
-        }
-        return Text::vCard::Precisely::V3::Node::N->new(\%param);
-    },
+coerce 'N', from 'HashRef[Maybe[Ref]|Maybe[Str]]', via {
+    my %param;
+    while ( my ( $key, $content ) = each %$_ ) {
+        $param{$key} = $content if $content;
+    }
+    return Text::vCard::Precisely::V3::Node::N->new( \%param );
+},
     from 'HashRef[Maybe[Str]]',
-    via { Text::vCard::Precisely::V3::Node::N->new($_) },
-    from 'ArrayRef[Maybe[Str]]',
-    via { Text::vCard::Precisely::V3::Node::N->new({
-        family      => $_->[0] || '',
-        given       => $_->[1] || '',
-        additional  => $_->[2] || '',
-        prefixes    => $_->[3] || '',
-        suffixes    => $_->[4] || '',
-    }) },
+    via { Text::vCard::Precisely::V3::Node::N->new($_) }, from 'ArrayRef[Maybe[Str]]', via {
+    Text::vCard::Precisely::V3::Node::N->new(
+        {   family     => $_->[0] || '',
+            given      => $_->[1] || '',
+            additional => $_->[2] || '',
+            prefixes   => $_->[3] || '',
+            suffixes   => $_->[4] || '',
+        }
+    )
+    },
     from 'Str',
-    via { Text::vCard::Precisely::V3::Node::N->new({ content => [split /(?<!\\);/, $_] }) };
+    via { Text::vCard::Precisely::V3::Node::N->new( { content => [ split /(?<!\\);/, $_ ] } ) };
 has n => ( is => 'rw', isa => 'N', coerce => 1 );
 
 =head2 tel()
@@ -470,11 +456,19 @@ has n => ( is => 'rw', isa => 'N', coerce => 1 );
 subtype 'Tels' => as 'ArrayRef[Text::vCard::Precisely::V3::Node::Tel]';
 coerce 'Tels',
     from 'Str',
-    via {[ Text::vCard::Precisely::V3::Node::Tel->new({ content => $_ }) ]},
-    from 'HashRef',
-    via {[       Text::vCard::Precisely::V3::Node::Tel->new({ %$_, types => [@{ $_->{'types'} || [] }] }) ]},
-    from 'ArrayRef[HashRef]',
-    via {[ map { Text::vCard::Precisely::V3::Node::Tel->new({ %$_, types => [@{ $_->{'types'} || [] }], %$_ }) } @$_ ]};
+    via { [ Text::vCard::Precisely::V3::Node::Tel->new( { content => $_ } ) ] },
+    from 'HashRef', via {
+    [   Text::vCard::Precisely::V3::Node::Tel->new(
+            { %$_, types => [ @{ $_->{'types'} || [] } ] }
+        )
+    ]
+    }, from 'ArrayRef[HashRef]', via {
+    [   map {
+            Text::vCard::Precisely::V3::Node::Tel->new(
+                { %$_, types => [ @{ $_->{'types'} || [] } ], %$_ } )
+        } @$_
+    ]
+    };
 has tel => ( is => 'rw', isa => 'Tels', coerce => 1 );
 
 =head2 adr(), address()
@@ -500,9 +494,9 @@ Accepts/returns an ArrayRef that looks like:
 subtype 'Address' => as 'ArrayRef[Text::vCard::Precisely::V3::Node::Address]';
 coerce 'Address',
     from 'HashRef',
-    via { [ Text::vCard::Precisely::V3::Node::Address->new($_) ] },
-    from 'ArrayRef[HashRef]',
-    via { [ map { Text::vCard::Precisely::V3::Node::Address->new($_) } @$_ ] };
+    via { [ Text::vCard::Precisely::V3::Node::Address->new($_) ] }, from 'ArrayRef[HashRef]', via {
+    [ map { Text::vCard::Precisely::V3::Node::Address->new($_) } @$_ ]
+    };
 has adr => ( is => 'rw', isa => 'Address', coerce => 1 );
 
 =head2 email()
@@ -523,11 +517,11 @@ or accept the string as email like below
 subtype 'Email' => as 'ArrayRef[Text::vCard::Precisely::V3::Node::Email]';
 coerce 'Email',
     from 'Str',
-    via { [ Text::vCard::Precisely::V3::Node::Email->new({ content => $_ }) ] },
+    via { [ Text::vCard::Precisely::V3::Node::Email->new( { content => $_ } ) ] },
     from 'HashRef',
-    via { [ Text::vCard::Precisely::V3::Node::Email->new($_) ] },
-    from 'ArrayRef[HashRef]',
-    via { [ map { Text::vCard::Precisely::V3::Node::Email->new($_) } @$_ ] };
+    via { [ Text::vCard::Precisely::V3::Node::Email->new($_) ] }, from 'ArrayRef[HashRef]', via {
+    [ map { Text::vCard::Precisely::V3::Node::Email->new($_) } @$_ ]
+    };
 has email => ( is => 'rw', isa => 'Email', coerce => 1 );
 
 =head2 url()
@@ -546,30 +540,31 @@ or accept the string as URL like below
 =cut
 
 subtype 'URLs' => as 'ArrayRef[Text::vCard::Precisely::V3::Node::URL]';
-coerce 'URLs',
-    from 'Str',
+coerce 'URLs', from 'Str', via {
+    my $name = uc [ split( /::/, [ caller(2) ]->[3] ) ]->[-1];
+    return [ Text::vCard::Precisely::V3::Node::URL->new( { name => $name, content => $_ } ) ]
+}, from 'HashRef[Str]', via {
+    my $name = uc [ split( /::/, [ caller(2) ]->[3] ) ]->[-1];
+    return [
+        Text::vCard::Precisely::V3::Node::URL->new(
+            {   name    => $name,
+                content => $_->{'content'}
+            }
+        )
+    ]
+}, from 'Object',    # Can't asign 'URI' or 'Object[URI]'
     via {
-        my $name = uc [split( /::/, [caller(2)]->[3] )]->[-1];
-        return [Text::vCard::Precisely::V3::Node::URL->new({ name => $name, content => $_ })]
-    },
-    from 'HashRef[Str]',
-    via  {
-        my $name = uc [split( /::/, [caller(2)]->[3] )]->[-1];
-        return [ Text::vCard::Precisely::V3::Node::URL->new({
-            name => $name,
-            content => $_->{'content'}
-        }) ]
-    },
-    from 'Object',    # Can't asign 'URI' or 'Object[URI]'
-    via {
-        my $name = uc [split( /::/, [caller(2)]->[3] )]->[-1];
-        return [Text::vCard::Precisely::V3::Node::URL->new({
-            name => $name,
-            content => $_->as_string(),
-        })]
-    },
-    from 'ArrayRef[HashRef]',
-    via  { [ map{ Text::vCard::Precisely::V3::Node::URL->new($_) } @$_ ] };
+    my $name = uc [ split( /::/, [ caller(2) ]->[3] ) ]->[-1];
+    return [
+        Text::vCard::Precisely::V3::Node::URL->new(
+            {   name    => $name,
+                content => $_->as_string(),
+            }
+        )
+    ]
+    }, from 'ArrayRef[HashRef]', via {
+    [ map { Text::vCard::Precisely::V3::Node::URL->new($_) } @$_ ]
+    };
 has url => ( is => 'rw', isa => 'URLs', coerce => 1 );
 
 =head2 photo(), logo()
@@ -581,41 +576,43 @@ Attention! Mac OS X and iOS B<ignore> the description beeing URL
 =cut
 
 subtype 'Photos' => as 'ArrayRef[Text::vCard::Precisely::V3::Node::Image]';
-coerce 'Photos',
-    from 'HashRef',
+coerce 'Photos', from 'HashRef', via {
+    my $name = uc [ split( /::/, [ caller(2) ]->[3] ) ]->[-1];
+    return [
+        Text::vCard::Precisely::V3::Node::Image->new(
+            {   name       => $name,
+                media_type => $_->{'media_type'} || $_->{'type'},
+                content    => $_->{'content'},
+            }
+        )
+    ]
+}, from 'ArrayRef[HashRef]', via {
+    [   map {
+            if ( ref $_->{types} eq 'ARRAY' ) {
+                ( $_->{'media_type'} ) = @{ $_->{'types'} };
+                delete $_->{'types'};
+            }
+            Text::vCard::Precisely::V3::Node::Image->new($_)
+        } @$_
+    ]
+}, from 'Str',    # when parse BASE64 encoded strings
     via {
-        my $name = uc [split( /::/, [caller(2)]->[3] )]->[-1];
-        return [ Text::vCard::Precisely::V3::Node::Image->new({
-            name => $name,
-            media_type => $_->{'media_type'} || $_->{'type'},
-            content => $_->{'content'},
-        }) ] },
-    from 'ArrayRef[HashRef]',
-    via { [ map{
-        if( ref $_->{types} eq 'ARRAY' ){
-            ( $_->{'media_type'} ) = @{$_->{'types'}};
-            delete $_->{'types'};
-        }
-        Text::vCard::Precisely::V3::Node::Image->new($_)
-    } @$_ ] },
-    from 'Str',   # when parse BASE64 encoded strings
+    my $name = uc [ split( /::/, [ caller(2) ]->[3] ) ]->[-1];
+    return [
+        Text::vCard::Precisely::V3::Node::Image->new(
+            {   name    => $name,
+                content => $_,
+            }
+        )
+    ]
+    }, from 'ArrayRef[Str]',    # when parse BASE64 encoded strings
     via {
-        my $name = uc [split( /::/, [caller(2)]->[3] )]->[-1];
-        return [ Text::vCard::Precisely::V3::Node::Image->new({
-            name => $name,
-            content => $_,
-        } ) ]
-    },
-    from 'ArrayRef[Str]',   # when parse BASE64 encoded strings
-    via {
-        my $name = uc [split( /::/, [caller(2)]->[3] )]->[-1];
-        return [ map{ Text::vCard::Precisely::V3::Node::Image->new({
-            name => $name,
-            content => $_,
-        }) } @$_ ]
-    },
-    from 'Object',   # when URI.pm is used
-    via { [ Text::vCard::Precisely::V3::Node::Image->new( { content => $_->as_string } ) ] };
+    my $name = uc [ split( /::/, [ caller(2) ]->[3] ) ]->[-1];
+    return [
+        map { Text::vCard::Precisely::V3::Node::Image->new( { name => $name, content => $_, } ) }
+            @$_ ]
+    }, from 'Object',           # when URI.pm is used
+    via { [ Text::vCard::Precisely::V3::Node::Image->new( { content => $_->as_string() } ) ] };
 has [qw| photo logo |] => ( is => 'rw', isa => 'Photos', coerce => 1 );
 
 =head2 note()
@@ -643,43 +640,46 @@ To specify information related to the global positioning of the object the vCard
 To specify a public key or authentication certificate associated with the object that the vCard represents
 
 =head2 label()
+
 ToDo: because B<It's DEPRECATED in 4.0>
 To specify the formatted text corresponding to delivery address of the object the vCard represents
 
 =cut
 
 subtype 'Node' => as 'ArrayRef[Text::vCard::Precisely::V3::Node]';
-coerce 'Node',
-    from 'Str',
-    via {
-        my $name = uc [split( /::/, [caller(2)]->[3] )]->[-1];
-        return [ Text::vCard::Precisely::V3::Node->new( { name => $name, content => $_ } ) ]
-    },
-    from 'HashRef',
-    via {
-        my $name = uc [split( /::/, [caller(2)]->[3] )]->[-1];
-        return [ Text::vCard::Precisely::V3::Node->new({
-            name => $_->{'name'} || $name,
-            types => $_->{'types'} || [],
-            content => $_->{'content'} || croak "No value in HashRef!",
-        }) ]
-    },
-    from 'ArrayRef[HashRef]',
-    via {
-        my $name = uc [split( /::/, [caller(2)]->[3] )]->[-1];
-        return [ map { Text::vCard::Precisely::V3::Node->new({
-            name => $_->{'name'} || $name,
-            types => $_->{'types'} || [],
-            content => $_->{'content'} || croak "No value in HashRef!",
-        }) } @$_ ]
-    };
-has [qw|note org title role categories fn nickname geo key label|]
-    => ( is => 'rw', isa => 'Node', coerce => 1 );
+coerce 'Node', from 'Str', via {
+    my $name = uc [ split( /::/, [ caller(2) ]->[3] ) ]->[-1];
+    return [ Text::vCard::Precisely::V3::Node->new( { name => $name, content => $_ } ) ]
+}, from 'HashRef', via {
+    my $name = uc [ split( /::/, [ caller(2) ]->[3] ) ]->[-1];
+    return [
+        Text::vCard::Precisely::V3::Node->new(
+            {   name    => $_->{'name'}    || $name,
+                types   => $_->{'types'}   || [],
+                content => $_->{'content'} || croak "No value in HashRef!",
+            }
+        )
+    ]
+}, from 'ArrayRef[HashRef]', via {
+    my $name = uc [ split( /::/, [ caller(2) ]->[3] ) ]->[-1];
+    return [
+        map {
+            Text::vCard::Precisely::V3::Node->new(
+                {   name    => $_->{'name'}    || $name,
+                    types   => $_->{'types'}   || [],
+                    content => $_->{'content'} || croak "No value in HashRef!",
+                }
+            )
+        } @$_
+    ]
+};
+has [qw|note org title role categories fn nickname geo key label|] =>
+    ( is => 'rw', isa => 'Node', coerce => 1 );
 
 =head2 sort_string()
 
 To specify the family name, given name or organization text to be used for national-language-specific sorting of the FN, N and ORG
-B<This method will be DEPRECATED in vCard4.0> Use SORT-AS param instead of it. (L<Text::vCard::Precisely::V4|https://github.com/worthmine/Text-vCard-Precisely/blob/master/lib/Text/vCard/Precisely/V4.pm> supports it)
+B<This method will be DEPRECATED in vCard4.0> Use SORT-AS param instead of it. (L<Text::vCard::Precisely::V4|https://metacpan.org/pod/Text::vCard::Precisely::V4> supports it)
 
 =cut
 
@@ -691,10 +691,9 @@ To specify a value that represents a globally unique identifier corresponding to
 
 =cut
 
-subtype 'UID'
-    => as 'Str'
-    => where { m/^urn:uuid:[A-F0-9]{8}-[A-F0-9]{4}-[A-F0-9]{4}-[A-F0-9]{4}-[A-F0-9]{12}$/is }
-    => message { "The UID you provided, $_, was not correct" };
+subtype 'UID' => as 'Str' =>
+    where {m/^urn:uuid:[A-F0-9]{8}-[A-F0-9]{4}-[A-F0-9]{4}-[A-F0-9]{4}-[A-F0-9]{12}$/is}
+=> message {"The UID you provided, $_, was not correct"};
 has uid => ( is => 'rw', isa => 'UID' );
 
 =head2 tz(), timezone()
@@ -708,12 +707,10 @@ So it just supports some text values
 =cut
 
 subtype 'TimeZones' => as 'ArrayRef[DateTime::TimeZone]';
-coerce 'TimeZones',
-    from 'ArrayRef',
-    via {[ map{ DateTime::TimeZone->new( name => $_ ) } @$_ ]},
-    from 'Str',
-    via {[ DateTime::TimeZone->new( name => $_ ) ]};
-has tz =>  ( is => 'rw', isa => 'TimeZones', coerce => 1 );
+coerce 'TimeZones', from 'ArrayRef', via {
+    [ map { DateTime::TimeZone->new( name => $_ ) } @$_ ]
+}, from 'Str', via { [ DateTime::TimeZone->new( name => $_ ) ] };
+has tz => ( is => 'rw', isa => 'TimeZones', coerce => 1 );
 
 =head2 bday(), birthday()
 
@@ -731,12 +728,9 @@ To specify the identifier for the product that created the vCard object
 =cut
 
 subtype 'ProdID' => as 'Str';
-coerce 'ProdID',
-    from 'ArrayRef[HashRef]',
-    via { $_[0]->[0]{'content'} };
+coerce 'ProdID', from 'ArrayRef[HashRef]', via { $_[0]->[0]{'content'} };
 has prodid => ( is => 'rw', isa => 'ProdID', coerce => 1 );
 
-
 =head2 source()
 
 To identify the source of directory information contained in the content type
@@ -760,8 +754,9 @@ subtype 'SocialProfile' => as 'ArrayRef[Text::vCard::Precisely::V3::Node::Social
 coerce 'SocialProfile',
     from 'HashRef',
     via { [ Text::vCard::Precisely::V3::Node::SocialProfile->new($_) ] },
-    from 'ArrayRef[HashRef]',
-    via { [ map { Text::vCard::Precisely::V3::Node::SocialProfile->new($_) } @$_ ] };
+    from 'ArrayRef[HashRef]', via {
+    [ map { Text::vCard::Precisely::V3::Node::SocialProfile->new($_) } @$_ ]
+    };
 has socialprofile => ( is => 'rw', isa => 'SocialProfile', coerce => 1 );
 
 __PACKAGE__->meta->make_immutable;
@@ -825,11 +820,11 @@ L<RFC 2425|https://tools.ietf.org/html/rfc2425>
 
 =item
 
-L<Text::vFile::asData|https://github.com/richardc/perl-text-vfile-asdata>
+L<Text::vFile::asData|https://metacpan.org/pod/Text::vFile::asData>
 
 =item
 
-L<Text::vCard::Precisely::V4 on GitHub|https://github.com/worthmine/Text-vCard-Precisely/blob/master/lib/Text/vCard/Precisely/V4.pm>
+L<Text::vCard::Precisely::V4|https://metacpan.org/pod/Text::vCard::Precisely::V4>
 
 =back
 
