@@ -1,6 +1,6 @@
 package Text::vCard::Precisely::V4;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 use Moose;
 use Moose::Util::TypeConstraints;
@@ -25,11 +25,11 @@ You can unlock types that will be available in vCard 4.0
  # Or you can write like below:
  #my $vc = Text::vCard::Precisely::V4->new();
 
-The Usage is same with L<Text::vCard::Precisely::V3|https://github.com/worthmine/Text-vCard-Precisely/blob/master/lib/Text/vCard/Precisely/V3.pm>
+The Usage is same with L<Text::vCard::Precisely::V3|https://metacpan.org/pod/Text::vCard::Precisely::V3>
 
 =head1 DESCRIPTION
 
-This module is an additional version for reading/writing for vCard 4.0. it's just a wrapper of L<Text::vCard::Precisely::V3|https://github.com/worthmine/Text-vCard-Precisely/blob/master/lib/Text/vCard/Precisely/V3.pm> with Moose.
+This module is an additional version for reading/writing for vCard 4.0. it's just a wrapper of L<Text::vCard::Precisely::V3|https://metacpan.org/pod/Text::vCard::Precisely::V3>
 
 B<Caution!> It's NOT be recommended because some reasons below:
 
@@ -92,7 +92,7 @@ You HAVE TO use encode_utf8() if your vCard is written in utf8
 
 =cut
 
-my $cr = "\x0D\x0A";
+my $cr    = "\x0D\x0A";
 my @types = qw(
     FN N NICKNAME
     ADR TEL EMAIL IMPP LANG GEO
@@ -108,11 +108,11 @@ sub as_string {
     my $str = $self->_header();
     $str .= $self->_make_types(@types);
 
-    $str .= 'KIND:' . $self->kind() . $cr if $self->kind();
-    $str .= 'BDAY:' . $self->bday() . $cr if $self->bday();
+    $str .= 'KIND:' . $self->kind() . $cr               if $self->kind();
+    $str .= 'BDAY:' . $self->bday() . $cr               if $self->bday();
     $str .= 'ANNIVERSARY:' . $self->anniversary() . $cr if $self->anniversary();
-    $str .= 'GENDER:' . $self->gender() . $cr if $self->gender();
-    $str .= 'UID:' . $self->uid() . $cr if $self->uid();
+    $str .= 'GENDER:' . $self->gender() . $cr           if $self->gender();
+    $str .= 'UID:' . $self->uid() . $cr                 if $self->uid();
     $str .= join '', @{ $self->member() } if $self->member();
     map { $str .= "CLIENTPIDMAP:$_" . $cr } @{ $self->clientpidmap() } if $self->clientpidmap();
 
@@ -158,29 +158,30 @@ The format is SAME as 3.0
 
 =cut
 
-subtype 'v4N'
-    => as 'Text::vCard::Precisely::V4::Node::N';
-coerce 'v4N',
-    from 'HashRef[Maybe[Ref]|Maybe[Str]]',
-    via {
-        my %param;
-        while( my ($key, $value) = each %$_ ) {
-            $param{$key} = $value if $value;
-        }
-        return Text::vCard::Precisely::V4::Node::N->new(\%param);
-    },
+subtype 'v4N' => as 'Text::vCard::Precisely::V4::Node::N';
+coerce 'v4N', from 'HashRef[Maybe[Ref]|Maybe[Str]]', via {
+    my %param;
+    while ( my ( $key, $value ) = each %$_ ) {
+        $param{$key} = $value if $value;
+    }
+    return Text::vCard::Precisely::V4::Node::N->new( \%param );
+},
     from 'HashRef[Maybe[Str]]',
-    via { Text::vCard::Precisely::V4::Node::N->new({ content => $_ }) },
-    from 'ArrayRef[Maybe[Str]]',
-    via { Text::vCard::Precisely::V4::Node::N->new({ content => {
-        family      => $_->[0] || '',
-        given       => $_->[1] || '',
-        additional  => $_->[2] || '',
-        prefixes    => $_->[3] || '',
-        suffixes    => $_->[4] || '',
-    } }) },
+    via { Text::vCard::Precisely::V4::Node::N->new( { content => $_ } ) },
+    from 'ArrayRef[Maybe[Str]]', via {
+    Text::vCard::Precisely::V4::Node::N->new(
+        {   content => {
+                family     => $_->[0] || '',
+                given      => $_->[1] || '',
+                additional => $_->[2] || '',
+                prefixes   => $_->[3] || '',
+                suffixes   => $_->[4] || '',
+            }
+        }
+    )
+    },
     from 'Str',
-    via { Text::vCard::Precisely::V4::Node::N->new({ content => [split /(?<!\\);/, $_] }) };
+    via { Text::vCard::Precisely::V4::Node::N->new( { content => [ split /(?<!\\);/, $_ ] } ) };
 has n => ( is => 'rw', isa => 'v4N', coerce => 1 );
 
 =head2 tel()
@@ -192,15 +193,22 @@ The format in as_string() is B<different from 3.0>, but the interface is SAME
 subtype 'v4Tels' => as 'ArrayRef[Text::vCard::Precisely::V4::Node::Tel]';
 coerce 'v4Tels',
     from 'Str',
-    via {[ Text::vCard::Precisely::V4::Node::Tel->new({ content => $_ }) ]},
-    from 'HashRef',
-    via {[
-        
-        Text::vCard::Precisely::V4::Node::Tel->new({ %$_, types => [@{ $_->{'types'} || [] }] })
-        
-        ]},
-    from 'ArrayRef[HashRef]',
-via {[ map{ Text::vCard::Precisely::V4::Node::Tel->new({ %$_, types => [@{ $_->{'types'} || [] }] }) } @$_ ]};
+    via { [ Text::vCard::Precisely::V4::Node::Tel->new( { content => $_ } ) ] },
+    from 'HashRef', via {
+    [
+
+        Text::vCard::Precisely::V4::Node::Tel->new(
+            { %$_, types => [ @{ $_->{'types'} || [] } ] }
+        )
+
+    ]
+    }, from 'ArrayRef[HashRef]', via {
+    [   map {
+            Text::vCard::Precisely::V4::Node::Tel->new(
+                { %$_, types => [ @{ $_->{'types'} || [] } ] } )
+        } @$_
+    ]
+    };
 has tel => ( is => 'rw', isa => 'v4Tels', coerce => 1 );
 
 =head2 adr(), address()
@@ -214,9 +222,9 @@ LABEL param and GEO param are now available
 subtype 'v4Address' => as 'ArrayRef[Text::vCard::Precisely::V4::Node::Address]';
 coerce 'v4Address',
     from 'HashRef',
-    via { [ Text::vCard::Precisely::V4::Node::Address->new($_) ] },
-    from 'ArrayRef[HashRef]',
-    via { [ map { Text::vCard::Precisely::V4::Node::Address->new($_) } @$_ ] };
+    via { [ Text::vCard::Precisely::V4::Node::Address->new($_) ] }, from 'ArrayRef[HashRef]', via {
+    [ map { Text::vCard::Precisely::V4::Node::Address->new($_) } @$_ ]
+    };
 has adr => ( is => 'rw', isa => 'v4Address', coerce => 1 );
 
 =head2 email()
@@ -234,41 +242,43 @@ The format is SAME as 3.0
 =cut
 
 subtype 'v4Photos' => as 'ArrayRef[Text::vCard::Precisely::V4::Node::Image]';
-coerce 'v4Photos',
-    from 'HashRef',
-    via  {
-        my $name = uc [split( /::/, [caller(2)]->[3] )]->[-1];
-        return [ Text::vCard::Precisely::V4::Node::Image->new({
-            name => $name,
-            media_type => $_->{media_type} || $_->{type},
-            content => $_->{content},
-    }) ] },
-    from 'ArrayRef[HashRef]',
-    via  { [ map{
-        if( ref $_->{types} eq 'ARRAY' ){
-            ( $_->{media_type} ) = @{$_->{types}};
-            delete $_->{types};
-        }
-        Text::vCard::Precisely::V4::Node::Image->new($_)
-    } @$_ ] },
-    from 'Str',   # when parse BASE64 encoded strings
-    via  {
-        my $name = uc [split( /::/, [caller(2)]->[3] )]->[-1];
-        return [ Text::vCard::Precisely::V4::Node::Image->new({
-            name => $name,
-            content => $_,
-        } ) ]
-    },
-    from 'ArrayRef[Str]',   # when parse BASE64 encoded strings
-    via  {
-        my $name = uc [split( /::/, [caller(2)]->[3] )]->[-1];
-        return [ map{ Text::vCard::Precisely::V4::Node::Image->new({
-            name => $name,
-            content => $_,
-        }) } @$_ ]
-    },
-    from 'Object',   # when URI.pm is used
-    via  { [ Text::vCard::Precisely::V4::Node::Image->new( { content => $_->as_string } ) ] };
+coerce 'v4Photos', from 'HashRef', via {
+    my $name = uc [ split( /::/, [ caller(2) ]->[3] ) ]->[-1];
+    return [
+        Text::vCard::Precisely::V4::Node::Image->new(
+            {   name       => $name,
+                media_type => $_->{media_type} || $_->{type},
+                content    => $_->{content},
+            }
+        )
+    ]
+}, from 'ArrayRef[HashRef]', via {
+    [   map {
+            if ( ref $_->{types} eq 'ARRAY' ) {
+                ( $_->{media_type} ) = @{ $_->{types} };
+                delete $_->{types};
+            }
+            Text::vCard::Precisely::V4::Node::Image->new($_)
+        } @$_
+    ]
+}, from 'Str',    # when parse BASE64 encoded strings
+    via {
+    my $name = uc [ split( /::/, [ caller(2) ]->[3] ) ]->[-1];
+    return [
+        Text::vCard::Precisely::V4::Node::Image->new(
+            {   name    => $name,
+                content => $_,
+            }
+        )
+    ]
+    }, from 'ArrayRef[Str]',    # when parse BASE64 encoded strings
+    via {
+    my $name = uc [ split( /::/, [ caller(2) ]->[3] ) ]->[-1];
+    return [
+        map { Text::vCard::Precisely::V4::Node::Image->new( { name => $name, content => $_, } ) }
+            @$_ ]
+    }, from 'Object',           # when URI.pm is used
+    via { [ Text::vCard::Precisely::V4::Node::Image->new( { content => $_->as_string() } ) ] };
 has [qw| photo logo |] => ( is => 'rw', isa => 'v4Photos', coerce => 1 );
 
 =head2 note()
@@ -308,34 +318,36 @@ The format is SAME as 3.0
 =cut
 
 subtype 'v4Node' => as 'ArrayRef[Text::vCard::Precisely::V4::Node]';
-coerce 'v4Node',
-    from 'Str',
-    via {
-        my $name = uc [split( /::/, [caller(2)]->[3] )]->[-1];
-        return [ Text::vCard::Precisely::V4::Node->new( { name => $name, content => $_ } ) ]
-    },
-    from 'HashRef',
-    via {
-        my $name = uc [split( /::/, [caller(2)]->[3] )]->[-1];
-        return [ Text::vCard::Precisely::V4::Node->new({
-            name => $_->{'name'} || $name,
-            types => $_->{'types'} || [],
-            sort_as => $_->{'sort_as'},
-            content => $_->{'content'} || croak "No value in HashRef!",
-        }) ]
-    },
-    from 'ArrayRef[HashRef]',
-    via {
-        my $name = uc [split( /::/, [caller(2)]->[3] )]->[-1];
-        return [ map { Text::vCard::Precisely::V4::Node->new({
-            name => $_->{'name'} || $name,
-            types => $_->{'types'} || [],
-            sort_as => $_->{'sort_as'},
-            content => $_->{'content'} || croak "No value in HashRef!",
-        }) } @$_ ]
-    };
-has [qw|note org title role categories fn nickname lang impp xml geo key|]
-    => ( is => 'rw', isa => 'v4Node', coerce => 1 );
+coerce 'v4Node', from 'Str', via {
+    my $name = uc [ split( /::/, [ caller(2) ]->[3] ) ]->[-1];
+    return [ Text::vCard::Precisely::V4::Node->new( { name => $name, content => $_ } ) ]
+}, from 'HashRef', via {
+    my $name = uc [ split( /::/, [ caller(2) ]->[3] ) ]->[-1];
+    return [
+        Text::vCard::Precisely::V4::Node->new(
+            {   name  => $_->{'name'}  || $name,
+                types => $_->{'types'} || [],
+                sort_as => $_->{'sort_as'},
+                content => $_->{'content'} || croak "No value in HashRef!",
+            }
+        )
+    ]
+}, from 'ArrayRef[HashRef]', via {
+    my $name = uc [ split( /::/, [ caller(2) ]->[3] ) ]->[-1];
+    return [
+        map {
+            Text::vCard::Precisely::V4::Node->new(
+                {   name  => $_->{'name'}  || $name,
+                    types => $_->{'types'} || [],
+                    sort_as => $_->{'sort_as'},
+                    content => $_->{'content'} || croak "No value in HashRef!",
+                }
+            )
+        } @$_
+    ]
+};
+has [qw|note org title role categories fn nickname lang impp xml geo key|] =>
+    ( is => 'rw', isa => 'v4Node', coerce => 1 );
 
 =head2 source(), sound()
 
@@ -349,15 +361,14 @@ They are the B<new method in 4.0>
 
 =cut
 
-has [qw|source sound url fburl caladruri caluri|]
-    => ( is => 'rw', isa => 'URLs', coerce => 1 );
+has [qw|source sound url fburl caladruri caluri|] => ( is => 'rw', isa => 'URLs', coerce => 1 );
 
 subtype 'Related' => as 'ArrayRef[Text::vCard::Precisely::V4::Node::Related]';
 coerce 'Related',
     from 'HashRef',
-    via { [ Text::vCard::Precisely::V4::Node::Related->new($_) ] },
-    from 'ArrayRef[HashRef]',
-    via { [ map { Text::vCard::Precisely::V4::Node::Related->new($_) } @$_ ] };
+    via { [ Text::vCard::Precisely::V4::Node::Related->new($_) ] }, from 'ArrayRef[HashRef]', via {
+    [ map { Text::vCard::Precisely::V4::Node::Related->new($_) } @$_ ]
+    };
 has related => ( is => 'rw', isa => 'Related', coerce => 1 );
 
 =head2 kind()
@@ -368,31 +379,21 @@ It's the B<new method in 4.0>
  
 =cut
 
-subtype 'KIND'
-    => as 'Str'
-    => where { m/^(:?individual|group|org|location|[a-z0-9\-]+|X-[a-z0-9\-]+)$/s }
-    => message { "The KIND you provided, $_, was not supported" };
+subtype 'KIND' => as 'Str' =>
+    where {m/^(?:individual|group|org|location|[a-z0-9\-]+|X-[a-z0-9\-]+)$/s}
+=> message {"The KIND you provided, $_, was not supported"};
 has kind => ( is => 'rw', isa => 'KIND' );
 
-
-subtype 'v4TimeStamp'
-    => as 'Str'
-    => where { m/^\d{8}T\d{6}(:?Z(:?-\d{2}(:?\d{2})?)?)?$/is  }
-    => message { "The TimeStamp you provided, $_, was not correct" };
-coerce 'v4TimeStamp',
-    from 'Str',
-    via {
-        m/^(\d{4})-?(\d{2})-?(\d{2})(:?T(\d{2}):?(\d{2}):?(\d{2})Z)?$/is;
-        return sprintf '%4d%02d%02dT%02d%02d%02dZ', $1, $2, $3, $4, $5, $6
-    },
-    from 'Int',
-    via {
-        my ( $s, $m, $h, $d, $M, $y ) = gmtime($_);
-        return sprintf '%4d%02d%02dT%02d%02d%02dZ', $y + 1900, $M + 1, $d, $h, $m, $s
-    },
-    from 'ArrayRef[HashRef]',
-    via { $_->[0]{content} };
-has rev => ( is => 'rw', isa => 'v4TimeStamp', coerce => 1  );
+subtype 'v4TimeStamp' => as 'Str' => where {m/^\d{8}T\d{6}(?:Z(?:-\d{2}(?:\d{2})?)?)?$/is}
+=> message {"The TimeStamp you provided, $_, was not correct"};
+coerce 'v4TimeStamp', from 'Str', via {
+    m/^(\d{4})-?(\d{2})-?(\d{2})(?:T(\d{2}):?(\d{2}):?(\d{2})Z)?$/is;
+    return sprintf '%4d%02d%02dT%02d%02d%02dZ', $1, $2, $3, $4, $5, $6
+}, from 'Int', via {
+    my ( $s, $m, $h, $d, $M, $y ) = gmtime($_);
+    return sprintf '%4d%02d%02dT%02d%02d%02dZ', $y + 1900, $M + 1, $d, $h, $m, $s
+}, from 'ArrayRef[HashRef]', via { $_->[0]{content} };
+has rev => ( is => 'rw', isa => 'v4TimeStamp', coerce => 1 );
 
 =head2 member(), clientpidmap()
 
@@ -405,15 +406,14 @@ It's the B<new method in 4.0>
 subtype 'MEMBER' => as 'ArrayRef[Text::vCard::Precisely::V4::Node::Member]';
 coerce 'MEMBER',
     from 'UID',
-    via {[ Text::vCard::Precisely::V4::Node::Member->new($_) ]},
-    from 'ArrayRef[UID]',
-    via {[ map{ Text::vCard::Precisely::V4::Node::Member->new({ content => $_ })} @$_ ]};
+    via { [ Text::vCard::Precisely::V4::Node::Member->new($_) ] }, from 'ArrayRef[UID]', via {
+    [ map { Text::vCard::Precisely::V4::Node::Member->new( { content => $_ } ) } @$_ ]
+    };
 has member => ( is => 'rw', isa => 'MEMBER', coerce => 1 );
 
-subtype 'CLIENTPIDMAP'
-    => as 'Str'
-    => where { m/^\d+;urn:uuid:[A-F0-9]{8}-[A-F0-9]{4}-[A-F0-9]{4}-[A-F0-9]{4}-[A-F0-9]{12}$/is }
-    => message { "The CLIENTPIDMAP you provided, $_, was not correct" };
+subtype 'CLIENTPIDMAP' => as 'Str' =>
+    where {m/^\d+;urn:uuid:[A-F0-9]{8}-[A-F0-9]{4}-[A-F0-9]{4}-[A-F0-9]{4}-[A-F0-9]{12}$/is}
+=> message {"The CLIENTPIDMAP you provided, $_, was not correct"};
 subtype 'CLIENTPIDMAPs' => as 'ArrayRef[CLIENTPIDMAP]';
 coerce 'CLIENTPIDMAPs', from 'Str', via { [$_] };
 has clientpidmap => ( is => 'rw', isa => 'CLIENTPIDMAPs', coerce => 1 );
@@ -540,7 +540,7 @@ L<RFC 6350|https://tools.ietf.org/html/rfc6350>
 
 =item
 
-L<Text::vCard::Precisely::V3 on GitHub|https://github.com/worthmine/Text-vCard-Precisely/blob/master/lib/Text/vCard/Precisely/V3.pm>
+L<Text::vCard::Precisely::V3|https://metacpan.org/pod/Text::vCard::Precisely::V3>
 
 =item
 
